#include "connectiondialog.h"
#include "ui_connectiondialog.h"
#include "paneldialog.h"
#include "libschremote.h"
#include <QNetworkInterface>
#include <QMessageBox>
#include <QtEndian>

ConnectionDialog::ConnectionDialog(QWidget *parent) : QDialog(parent), ui(new Ui::ConnectionDialog)
  {
  ui->setupUi(this);

  //Make SIGNAL SLOT link between widgets and functions
  connect(ui->searchButton, SIGNAL(clicked()), this, SLOT(performSearch()));
  connect(ui->connectButton, SIGNAL(clicked()), this, SLOT(connectPress()));
  connect(ui->discoverList, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(itemSelect(QListWidgetItem*)));
  connect(ui->selectedEdit, SIGNAL(textChanged(QString)), this, SLOT(addresChange(QString)));
  connect(ui->exitButton, SIGNAL(clicked()), this, SLOT(close()));

  performSearch();
  }

ConnectionDialog::~ConnectionDialog()
  {
  delete ui;
  }

void ConnectionDialog::performSearch()
  {
  //Disable and clear some widgets
  ui->searchButton->setEnabled(false);
  ui->connectButton->setEnabled(false);
  ui->selectedEdit->clear();
  ui->discoverList->clear();
  ui->statusLabel->setText(tr("Look for interfaces..."));

  //Get the list of all interfaces on the PC
  bool found = 0;
  QList<QNetworkInterface> interfaces =	QNetworkInterface::allInterfaces();
  foreach (const QNetworkInterface &i, interfaces)
  if ((i.flags() & (QNetworkInterface::IsUp | QNetworkInterface::IsRunning)) ==
    (QNetworkInterface::IsUp | QNetworkInterface::IsRunning))
    {
    //Get list of addresses of to a interface
    QList<QNetworkAddressEntry> addresses = i.addressEntries();
    foreach (const QNetworkAddressEntry &addr, addresses)
    if (addr.broadcast().protocol() == QAbstractSocket::IPv4Protocol)
      {
      QString addr_txt(addr.broadcast().toString());
      ui->statusLabel->setText(tr("Probe %1").arg(addr_txt));
      //Process any events to avoid progam to be busy
      QApplication::processEvents();
      //Do a discover query
      SR_IPLIST *ip_list = sr_discover(addr_txt.toAscii().constData());
      if (ip_list)
        {
        SR_IPLIST *ip = ip_list;
        while (ip)
          {
          ui->discoverList->addItem(QHostAddress(qbswap<quint32>(ip->ip)).toString());
          ip = ip->next;
          }
        sr_discover_free(ip_list);
        }
      }
    }

  //Enable some widgets
  ui->searchButton->setEnabled(true);
  ui->statusLabel->setText(found ? tr("Seach complete") : tr("Search failed to discover any device"));
  }

void ConnectionDialog::itemSelect(QListWidgetItem* sel)
  {
  ui->selectedEdit->setText(sel->text());
  }

void ConnectionDialog::addresChange(const QString & text)
  {
  ui->connectButton->setEnabled(text.length());
  }

void ConnectionDialog::connectPress()
  {
  SR_HANDLE srh = sr_open_eth(ui->selectedEdit->text().toAscii().constData());
  if (!srh)
    {
    QMessageBox::critical(this, tr("Error"), tr("Failed to make a connection"));
    return;
    }

  PanelDialog *p = new PanelDialog(srh);
  p->show();
  close();
  }
