#include <stdio.h>
#include "panel.h"

Panel::Panel(SR_HANDLE s)
  {
  srh = s;
  for (int i=0; i<PANEL_LEN; i++)
    {
    old1[i] = 0;
    old2[i] = 0;
    }
  setupDevice();
  setupPanel();
  }

Panel::~Panel()
  {
  sr_close(srh);
  }

void Panel::setupDevice()
  {
  for (int i=0; i<12; i++)
    sr_pin_setup(srh, i, sr_pt_din_pullup);
  sr_i2c_enable(srh, 0, 400000);
  }

void Panel::setupPanel()
  {
  unsigned char data[2];
  data[0] = 4; //Configuration register
  data[1] = 1; //Enable display
  for (int i=0; i<PANEL_LEN; i+=2)
    sr_i2c_write_arr(srh, 0, PANEL_I2C+i, data, 2);
  }


void Panel::setText(const char* line1, const char* line2)
  {
  for (int i=0; i<PANEL_LEN; i+=2)
    {
    bool update = 0;
    char c1 = *line1 ? *line1++ : ' '; //Get next char and use ' ' if is out of length
    char c2 = *line2 ? *line2++ : ' '; //Get next char and use ' ' if is out of length
    if (old1[i] != c1)
      {
      old1[i] = c1;
      update = 1;
      }
    if (old2[i] != c2)
      {
      old2[i] = c2;
      update = 1;
      }
    //Get another character, 1 chip update 4 chars at onece
    c1 = *line1 ? *line1++ : ' '; //Get next char and use ' ' if is out of length
    c2 = *line2 ? *line2++ : ' '; //Get next char and use ' ' if is out of length
    if (old1[i+1] != c1)
      {
      old1[i+1] = c1;
      update = 1;
      }
    if (old2[i+1] != c2)
      {
      old2[i+1] = c2;
      update = 1;
      }
    if (update)
      {
      unsigned char data[5] = {0x60 /*Write Digit*/, old1[i+1], old1[i], old2[i+1], old2[i] };
      sr_i2c_write_arr(srh, 0, PANEL_I2C+i, data, 5);
      }
    }
  }

void Panel::setIntensity(int level)
  {
  if (level < 0) level = 0;
  else if (level > 15) level = 15;
  unsigned char data[3];
  data[0] = 1; //Intensity register
  data[1] = data[2] = (level<<4) | level; //Enable display
  for (int i=0; i<PANEL_LEN; i+=2)
    sr_i2c_write_arr(srh, 0, PANEL_I2C+i, data, 3);
  }
