#include "paneldialog.h"
#include "ui_paneldialog.h"
#include "QDateTime"

PanelDialog::PanelDialog(SR_HANDLE s, QWidget *parent) : QDialog(parent), ui(new Ui::PanelDialog)
  {
  ui->setupUi(this);
  timer = new QTimer(this);
  timer->setInterval(250);
  panel = new Panel(s);
  connect(ui->intSlider, SIGNAL(valueChanged(int)), this, SLOT(intChange(int)));
  connect(ui->setButton, SIGNAL(clicked()), this, SLOT(setPress()));
  connect(ui->timerButton, SIGNAL(clicked()), this, SLOT(timerToggle()));
  connect(timer, SIGNAL(timeout()), this, SLOT(timerUpdate()));
  connect(ui->exitButton, SIGNAL(clicked()), this, SLOT(close()));
  }

PanelDialog::~PanelDialog()
  {
  delete ui;
  delete panel;
  }

void PanelDialog::intChange(int i)
  {
  panel->setIntensity(i-1);
  }

void PanelDialog::setPress()
  {
  panel->setText(ui->lineEdit1->text().toAscii().constData(), ui->lineEdit2->text().toAscii().constData());
  }

void PanelDialog::timerToggle()
  {
  if (timer->isActive())
    {
    timer->stop();
    ui->timerButton->setText(tr("Start timer"));
    ui->setButton->setEnabled(true);
    }
  else
    {
    timer->start();
    ui->timerButton->setText(tr("Stop timer"));
    ui->setButton->setEnabled(false);
    }
  }

void PanelDialog::timerUpdate()
  {
  static const char* wdays[7] = {"Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"};
  QDateTime date = QDateTime::currentDateTime();
  QString line1 = QString(" %4 %1-%2-%3").arg(date.date().day(), 2, 10, QChar('0')).arg(date.date().month(), 2, 10, QChar('0')).arg(date.date().year())
    .arg(wdays[date.date().dayOfWeek()-1]);
  int dots = date.time().msec()/250+1;
  QString line2 = QString("%1%2%3:%4:%5%6%7")
    .arg(QString(dots, '>')).arg(QString(4-dots, ' '))
    .arg(date.time().hour(), 2, 10, QChar('0')).arg(date.time().minute(), 2, 10, QChar('0')).arg(date.time().second(), 2, 10, QChar('0'))
    .arg(QString(4-dots, ' ')).arg(QString(dots, '<'));

  panel->setText(line1.toAscii().constData(), line2.toAscii().constData());
  }
